@@ -147,10 +147,14 @@ class PyotRequestToken:
     _tries: int = 0
     _raise_at: int = 1
     _exception: Any = None
+    _code: int = 0
 
     async def stream(self, code: int, how: Tuple, origin: str):
         strategy = how[0]
         params = how[1]
+        if self._code != code:
+            self._exception = None
+            self._code = code
 
         if self._exception is None:
             if code == 404:
@@ -174,9 +178,11 @@ class PyotRequestToken:
 
             if strategy != "T":
                 self._raise_at = params[-1]+1
+            else:
+                self._raise_at = 1
         
         self._tries += 1
-        if strategy == "E":
+        if strategy == "E" and self._tries < self._raise_at:
             await asyncio.sleep(params[0]**self._tries)
 
     async def run_or_raise(self):
@@ -195,9 +201,9 @@ class PyotErrorHandler:
         408 : ("E", [3, 3]),
         429 : ("E", [3, 3]),
         500 : ("E", [3, 3]),
-        502 : ("R", [3]),
+        502 : ("E", [3, 3]),
         503 : ("E", [3, 3]),
-        504 : ("R", [3]),
+        504 : ("E", [3, 3]),
         888 : ("T", []),
     }
 
@@ -228,4 +234,4 @@ class PyotErrorHandler:
                 raise RuntimeError(f"Handler strategy '{strategy}' is not a valid token for error handling")
         hand = copy.deepcopy(self.default_handler)
         hand.update(handler)
-        return hand
\ No newline at end of file
+        return hand
