@@ -1,4 +1,7 @@
-from .djangocache import DjangoCache
+try:
+    from .djangocache import DjangoCache
+except ImportError:
+    pass
 from .riotapi import RiotAPI
 from .omnistone import Omnistone
 from .merakicdn import MerakiCDN
